summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorschmidt <douglascraigschmidt@users.noreply.github.com>2006-02-21 18:05:29 +0000
committerschmidt <douglascraigschmidt@users.noreply.github.com>2006-02-21 18:05:29 +0000
commit16bec739040ad37b629faf7716ebf429b7957c7c (patch)
tree93521fea69e026931019120a53b4da7940064ca2
parent4d4dc49485fd6d9d98ac13c858eba6c44d96abbb (diff)
downloadATCD-16bec739040ad37b629faf7716ebf429b7957c7c.tar.gz
ChangeLogTag:Fri Feb 17 08:15:57 2006 Douglas C. Schmidt <schmidt@cse.wustl.edu>
-rw-r--r--ChangeLog10
-rw-r--r--THANKS1
-rw-r--r--ace/Asynch_Acceptor.h4
-rw-r--r--ace/Default_Constants.h4
4 files changed, 17 insertions, 2 deletions
diff --git a/ChangeLog b/ChangeLog
index f351dcd8937..c574453ae74 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,13 @@
+Fri Feb 17 08:15:57 2006 Douglas C. Schmidt <schmidt@cse.wustl.edu>
+
+ * ace/Asynch_Acceptor.h: Used ACE_DEFAULT_ASYNCH_BACKLOG instead
+ of ACE_DEFAULT_BACKLOG since the latter is set to a huge value
+ on Windows. Thanks to Alex Libman and Daniel <__daniel___ at icg
+ do tu-graz dot ac dot at> for their help.
+
+ * ace/Default_Constants.h: Added a new macro called
+ ACE_DEFAULT_ASYNCH_BACKLOG that defaults to 5.
+
Mon Feb 20 15:03:01 2006 Wallace Zhang <zhangw@ociweb.com>
* ACE version 5.4.10 released.
diff --git a/THANKS b/THANKS
index 192d7496406..41f41eb5ff2 100644
--- a/THANKS
+++ b/THANKS
@@ -2068,6 +2068,7 @@ William Byrne <williamb at codics dot com>
Karl Schmitt <Karl dot Schmitt at dfs dot de>
Ron DeAngelis <rdeangel at rite-solutions dot com>
Alex Sheh <ASHEH at euphonix dot com>
+Daniel Wagner <__daniel___ at icg do tu-graz dot ac dot at>
I would particularly like to thank Paul Stephenson, who worked with me
at Ericsson in the early 1990's. Paul devised the recursive Makefile
diff --git a/ace/Default_Constants.h b/ace/Default_Constants.h
index f3011c86da6..945e9ff3513 100644
--- a/ace/Default_Constants.h
+++ b/ace/Default_Constants.h
@@ -74,6 +74,10 @@
# define ACE_DEFAULT_BACKLOG 5
# endif /* ACE_DEFAULT_BACKLOG */
+# if !defined (ACE_DEFAULT_ASYNCH_BACKLOG)
+# define ACE_DEFAULT_ASYNCH_BACKLOG 5
+# endif /* ACE_DEFAULT_ASYNCH_BACKLOG */
+
# if !defined (ACE_DEFAULT_THREADS)
# define ACE_DEFAULT_THREADS 1
# endif /* ACE_DEFAULT_THREADS */
diff --git a/ace/Asynch_Acceptor.h b/ace/Asynch_Acceptor.h
index 3664a04c673..e8cb490794d 100644
--- a/ace/Asynch_Acceptor.h
+++ b/ace/Asynch_Acceptor.h
@@ -72,7 +72,7 @@ public:
* associated @c ACE_Service_Handler::addresses() method
* after any call to @c validate_new_connection() and prior
* to the @c open() hook method call.
* @param backlog Optional, defaulting to @c ACE_DEFAULT_BACKLOG (which
* can be adjusted in your platform's @c config.h file).
* Specifies the listening backlog for the listening socket.
* @param reuse_addr Optional, indicates whether the @c SO_REUSEADDR
@@ -109,7 +109,7 @@ public:
virtual int open (const ACE_INET_Addr &address,
size_t bytes_to_read = 0,
int pass_addresses = 0,
- int backlog = ACE_DEFAULT_BACKLOG,
+ int backlog = ACE_DEFAULT_ASYNCH_BACKLOG,
int reuse_addr = 1,
ACE_Proactor *proactor = 0,
int validate_new_connection = 0,
@@ -72,7 +72,7 @@ public:
* after any call to @c validate_new_connection() and prior
* to the @c open() hook method call.
- * @param backlog Optional, defaulting to @c ACE_DEFAULT_BACKLOG (which
+ * @param backlog Optional, defaulting to @c ACE_DEFAULT_ASYNCH_BACKLOG (which
* can be adjusted in your platform's @c config.h file).
* Specifies the listening backlog for the listening socket.